@@ -4,6 +4,8 @@ import warnings
 from django import template
 from django_assets import Bundle
 from django_assets.env import get_env
+
+from webassets import six
 from webassets.exceptions import ImminentDeprecationWarning
 
 
@@ -26,16 +28,17 @@ class AssetsNode(template.Node):
     # For testing, to inject a mock bundle
     BundleClass = Bundle
 
-    def __init__(self, filters, output, debug, files, childnodes):
+    def __init__(self, filters, depends, output, debug, files, childnodes):
         self.childnodes = childnodes
         self.output = output
         self.files = files
+        self.depends = depends
         self.filters = filters
         self.debug = debug
 
     def resolve(self, context={}):
         """We allow variables to be used for all arguments; this function
-        resolves all data against a given context;
+        resolves all data against a given context.
 
         This is a separate method as the management command must have
         the ability to check if the tag can be resolved without a context.
@@ -50,6 +53,16 @@ class AssetsNode(template.Node):
                     # Django seems to hide those; we don't want to expose
                     # them either, I guess.
                     raise
+        def resolve_depends(x):
+            # Adapter to parse django template tags for depends.
+            # into a webassets compabitble list if multiple depends is passed.
+            # Django templates support depends in a (comma delimited form. e.g.,
+            #
+            # {% assets filters="jsmin", output="path/to/file.js", depends="watchfile.js,second/watch/file.js" "projectfile.js" %}
+            value = resolve_var(x)
+            if isinstance(value, six.text_type):
+                value = value.split(',')
+            return value
         def resolve_bundle(name):
             # If a bundle with that name exists, use it. Otherwise,
             # assume a filename is meant.
@@ -58,10 +71,12 @@ class AssetsNode(template.Node):
             except KeyError:
                 return name
 
+
         return self.BundleClass(
             *[resolve_bundle(resolve_var(f)) for f in self.files],
             **{'output': resolve_var(self.output),
             'filters': resolve_var(self.filters),
+            'depends': resolve_depends(self.depends),
             'debug': parse_debug_value(resolve_var(self.debug))})
 
     def render(self, context):
@@ -82,6 +97,7 @@ def assets(parser, token):
     filters = None
     output = None
     debug = None
+    depends = None
     files = []
 
     # parse the arguments
@@ -116,6 +132,10 @@ def assets(parser, token):
                           'template tag has been renamed to '
                           '"filters" for consistency reasons.',
                             ImminentDeprecationWarning)
+        elif name == 'depends':
+
+
+            depends = value
         # positional arguments are source files
         elif name is None:
             files.append(value)
@@ -125,7 +145,7 @@ def assets(parser, token):
     # capture until closing tag
     childnodes = parser.parse(("endassets",))
     parser.delete_first_token()
-    return AssetsNode(filters, output, debug, files, childnodes)
+    return AssetsNode(filters, depends, output, debug, files, childnodes)
 
 
 
